def test_fixture(testdir):
    testdir.makepyfile(
        """
    from click.testing import CliRunner

    def test_fixture(cli_runner):
        assert isinstance(cli_runner, CliRunner)
    """
    )
    result = testdir.runpytest("--verbose")
    result.stdout.fnmatch_lines("test_fixture.py::test_fixture PASSED*")


def test_real_invocation(testdir):
    testdir.makepyfile(
        """
    import click

    def test_fixture(cli_runner):

        @click.command()
        @click.argument('name')
        def hello(name):
            click.echo('Hello %s!' % name)

        result = cli_runner.invoke(hello, ['Peter'])
        assert result.exit_code == 0
        assert result.output == 'Hello Peter!\\n'
    """
    )
    result = testdir.runpytest("--verbose")
    result.stdout.fnmatch_lines("test_real_invocation.py::test_fixture PASSED*")


def test_runner_setup(testdir):
    testdir.makepyfile(
        """
    import pytest

    @pytest.mark.runner_setup(charset='cp1251', env={'test': 1}, echo_stdin=True)
    def test_runner_setup(cli_runner):
        assert cli_runner.charset == 'cp1251'
        assert cli_runner.env == {'test': 1}
        assert cli_runner.echo_stdin
    """
    )
    result = testdir.runpytest("--verbose")
    result.stdout.fnmatch_lines("test_runner_setup.py::test_runner_setup PASSED*")


def test_docstring(testdir):
    result = testdir.runpytest("--fixtures")
    assert (
        "    Instance of `click.testing.CliRunner`. Can be "
        "configured with `@pytest.mark.runner_setup`." in result.stdout.lines
    )



def test_markers(testdir):
    result = testdir.runpytest("--markers")
    assert (
        "@pytest.mark.runner_setup(**kwargs): "
        "Pass kwargs to `click.testing.CliRunner` initialization." in result.stdout.lines
    )



def test_fixture(testdir):
    testdir.makeconftest(
        """
    try:
        from mock import patch, Mock
    except ImportError:
        from unittest.mock import patch, Mock

    def pytest_configure(config):
        config.patched = patch('pytest_click.fixtures.CliRunner.isolated_filesystem')
        config.patched.start()

    def pytest_unconfigure(config):
        config.patched.stop()
    """
    )
    testdir.makepyfile(
        """
    from click.testing import CliRunner

    def test_fixture(isolated_cli_runner):
        assert isinstance(isolated_cli_runner, CliRunner)
        assert isolated_cli_runner.isolated_filesystem.called
    """
    )
    result = testdir.runpytest("--verbose")
    result.stdout.fnmatch_lines("test_fixture.py::test_fixture PASSED*")


def test_real_invocation(testdir):
    testdir.makepyfile(
        """
    import click

    def test_fixture(isolated_cli_runner):

        @click.command()
        @click.argument('f', type=click.File())
        def cat(f):
            click.echo(f.read())

        with open('hello.txt', 'w') as f:
            f.write('Hello World!')

        result = isolated_cli_runner.invoke(cat, ['hello.txt'])
        assert result.exit_code == 0
        assert result.output == 'Hello World!\\n'
    """
    )
    result = testdir.runpytest("--verbose")
    result.stdout.fnmatch_lines("test_real_invocation.py::test_fixture PASSED*")


def test_docstring(testdir):
    result = testdir.runpytest("--fixtures")
    assert (
        "    Instance of `click.testing.CliRunner` with "
        "automagically `isolated_filesystem()` called." in result.stdout.lines
    )



#!/usr/bin/env python
from os import path

from setuptools import find_packages, setup

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "README.rst")) as fd:
    long_description = fd.read()

requirements = [
    "click>=6.0",
    "pytest>=5.0",
]

setup(
    name="pytest_click",
    version="1.1.0",
    url="https://github.com/Stranger6667/pytest-click",
    license="MIT",
    author="Dmitry Dygalo",
    author_email="dadygalo@gmail.com",
    maintainer="Dmitry Dygalo",
    maintainer_email="dadygalo@gmail.com",
    description="Pytest plugin for Click",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Software Development :: Testing",
    ],
    include_package_data=True,
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    install_requires=requirements,
    entry_points={
        "pytest11": [
            "pytest_click = pytest_click",
        ]
    },
)
